Struct Mode
pub struct Mode {
pub dimensions: (i32, i32),
pub refresh_rate: i32,
pub current: bool,
pub preferred: bool,
}Available on crate feature
wayland and Linux only.Fields
dimensions: (i32, i32)Number of pixels of this mode in format (width, height)
for example (1920, 1080)
refresh_rate: i32Refresh rate for this mode.
The refresh rate is specified in terms of millihertz (mHz). To convert approximately to Hertz, divide the value by 1000.
This value could be zero if an output has no correct refresh rate, such as a virtual output.
current: boolWhether this is the current mode for this output.
Per the Wayland protocol, non-current modes are deprecated and clients should not rely on deprecated modes.
preferred: boolWhether this is the preferred mode for this output.